@@ -22,7 +22,6 @@
  */
 
 #include "config.h"
-#include "galias.h"
 
 #include "gkeyfile.h"
 
@@ -61,6 +60,8 @@
 #include "gstrfuncs.h"
 #include "gutils.h"
 
+#include "galias.h"
+
 typedef struct _GKeyFileGroup GKeyFileGroup;
 
 struct _GKeyFile
@@ -342,6 +343,8 @@ find_file_in_data_dirs (const gchar   *file,
   if (output_file != NULL && fd > 0)
     *output_file = g_strdup (path);
 
+  g_free (path);
+
   return fd;
 }
 
@@ -1605,8 +1608,7 @@ g_key_file_get_locale_string (GKeyFile     *key_file,
  *
  * Returns the values associated with @key under @group_name
  * translated in the given @locale if available.  If @locale is
- * %NULL then the current locale is assumed. If @group_name is
- * %NULL, then the start group is used.
+ * %NULL then the current locale is assumed. 
 
  * If @key cannot be found then %NULL is returned and @error is set to
  * #G_KEY_FILE_ERROR_KEY_NOT_FOUND. If the values associated
@@ -1671,8 +1673,7 @@ g_key_file_get_locale_string_list (GKeyFile     *key_file,
  *
  * Associates a list of string values for @key and @locale under
  * @group_name.  If the translation for @key cannot be found then
- * it is created. If @group_name is %NULL, the start group is
- * used.
+ * it is created. 
  *
  * Since: 2.6
  **/
@@ -1721,7 +1722,7 @@ g_key_file_set_locale_string_list (GKeyFile            *key_file,
  * @error: return location for a #GError
  *
  * Returns the value associated with @key under @group_name as a
- * boolean. If @group_name is %NULL, the start group is used.
+ * boolean. 
  *
  * If @key cannot be found then the return value is undefined and
  * @error is set to #G_KEY_FILE_ERROR_KEY_NOT_FOUND. Likewise, if
@@ -1786,8 +1787,7 @@ g_key_file_get_boolean (GKeyFile     *key_file,
  * @value: %TRUE or %FALSE
  *
  * Associates a new boolean value with @key under @group_name.
- * If @key cannot be found then it is created. If @group_name
- * is %NULL, the start group is used.
+ * If @key cannot be found then it is created. 
  *
  * Since: 2.6
  **/
@@ -2003,8 +2003,7 @@ g_key_file_get_integer (GKeyFile     *key_file,
  * @value: an integer value
  *
  * Associates a new integer value with @key under @group_name.
- * If @key cannot be found then it is created. If @group_name
- * is %NULL, the start group is used.
+ * If @key cannot be found then it is created. 
  *
  * Since: 2.6
  **/
@@ -2106,7 +2105,6 @@ g_key_file_get_integer_list (GKeyFile     *key_file,
  *
  * Associates a list of integer values with @key under
  * @group_name.  If @key cannot be found then it is created.
- * If @group_name is %NULL the start group is used.
  *
  * Since: 2.6
  **/
@@ -2567,8 +2565,7 @@ g_key_file_has_group (GKeyFile    *key_file,
  * @error: return location for a #GError
  *
  * Looks whether the key file has the key @key in the group
- * @group_name. If @group_name is %NULL, the start group is
- * used.
+ * @group_name. 
  *
  * Return value: %TRUE if @key is a part of @group_name, %FALSE
  * otherwise.
@@ -3014,6 +3011,13 @@ g_key_file_parse_value_as_string (GKeyFile     *key_file,
               *q = '\\';
               break;
 
+	    case '\0':
+	      g_set_error (error, G_KEY_FILE_ERROR,
+			   G_KEY_FILE_ERROR_INVALID_VALUE,
+			   _("Key file contains escape character "
+			     "at end of line"));
+	      break;
+
             default:
 	      if (pieces && *p == key_file->list_separator)
 		*q = key_file->list_separator;
@@ -3049,15 +3053,13 @@ g_key_file_parse_value_as_string (GKeyFile     *key_file,
 	    }
 	}
 
+      if (*p == '\0')
+	break;
+
       q++;
       p++;
     }
 
-  if (p > value && p[-1] == '\\' && q[-1] != '\\' && *error == NULL)
-    g_set_error (error, G_KEY_FILE_ERROR,
-		 G_KEY_FILE_ERROR_INVALID_VALUE,
-		 _("Key file contains escape character at end of line"));
-
   *q = '\0';
   if (pieces)
   {
@@ -3267,4 +3269,5 @@ g_key_file_parse_comment_as_value (GKeyFile      *key_file,
   return value;
 }
 
-
+#define __G_KEY_FILE_C__
+#include "galiasdef.c"
